@@ -18,8 +18,9 @@ import uuid
 
 import mockito
 import pytest
-from iqm_client.iqm_client import IQMClient, RunResult, RunStatus
+from iqm_client.iqm_client import IQMClient, RunResult, RunStatus, Status
 from mockito import mock, when
+from qiskit import QuantumCircuit
 from qiskit.providers import JobStatus
 from qiskit.result import Counts
 from qiskit.result import Result as QiskitResult
@@ -31,7 +32,7 @@ from qiskit_iqm import IQMBackend, IQMJob
 def job():
     client = mock(IQMClient)
     backend = IQMBackend(client)
-    return IQMJob(backend, str(uuid.uuid4()), shots=4)
+    return IQMJob(backend, str(uuid.uuid4()))
 
 
 @pytest.fixture()
@@ -51,6 +52,13 @@ def iqm_result_two_registers():
     }
 
 
+@pytest.fixture()
+def iqm_metadata():
+    return {
+        'shots': 4,
+        'circuits': [{'name': 'circuit_1', 'instructions': []}]
+    }
+
 def test_submit_raises(job):
     with pytest.raises(NotImplementedError, match='Instead, use IQMBackend.run to submit jobs.'):
         job.submit()
@@ -62,32 +70,32 @@ def test_cancel_raises(job):
 
 
 def test_status_for_ready_result(job):
-    job._result = [['11', '10', '10']]
+    job._result = [('circuit_1', ['11', '10', '10'])]
     assert job.status() == JobStatus.DONE
     result = job.result()
     assert isinstance(result, QiskitResult)
     assert result.get_memory() == ['11', '10', '10']
 
 
-def test_status_done(job):
-    client_result = RunResult(status=RunStatus.READY, measurements=None)
+def test_status_done(job, iqm_metadata):
+    client_result = RunResult(status=Status.READY, measurements=None, metadata=iqm_metadata)
     when(job._client).get_run_status(uuid.UUID(job.job_id())).thenReturn(client_result)
     assert job.status() == JobStatus.DONE
     assert job._result is None
 
 
 def test_status_running(job):
-    when(job._client).get_run_status(uuid.UUID(job.job_id())).thenReturn(RunResult(status=RunStatus.PENDING))
+    when(job._client).get_run_status(uuid.UUID(job.job_id())).thenReturn(RunStatus(status=Status.PENDING))
     assert job.status() == JobStatus.RUNNING
 
 
 def test_status_fail(job):
-    when(job._client).get_run_status(uuid.UUID(job.job_id())).thenReturn(RunResult(status=RunStatus.FAILED))
+    when(job._client).get_run_status(uuid.UUID(job.job_id())).thenReturn(RunStatus(status=Status.FAILED))
     assert job.status() == JobStatus.ERROR
 
 
-def test_result(job, iqm_result_two_registers):
-    client_result = RunResult(status=RunStatus.READY, measurements=[iqm_result_two_registers])
+def test_result(job, iqm_result_two_registers, iqm_metadata):
+    client_result = RunResult(status=Status.READY, measurements=[iqm_result_two_registers], metadata=iqm_metadata)
     when(job._client).wait_for_results(uuid.UUID(job.job_id())).thenReturn(client_result)
 
     result = job.result()
@@ -104,7 +112,15 @@ def test_result(job, iqm_result_two_registers):
     mockito.verify(job._client, times=1).wait_for_results(uuid.UUID(job.job_id()))
 
 def test_result_multiple_circuits(job, iqm_result_two_registers):
-    client_result = RunResult(status=RunStatus.READY, measurements=[iqm_result_two_registers, iqm_result_two_registers])
+    iqm_metadata_multiple_circuits = {
+        'shots': 4,
+        'circuits': [{'name': 'circuit_1', 'instructions': []}, {'name': 'circuit_2', 'instructions': []}]
+    }
+    client_result = RunResult(
+        status=Status.READY,
+        measurements=[iqm_result_two_registers, iqm_result_two_registers],
+        metadata=iqm_metadata_multiple_circuits
+    )
     when(job._client).wait_for_results(uuid.UUID(job.job_id())).thenReturn(client_result)
 
     result = job.result()
@@ -113,3 +129,5 @@ def test_result_multiple_circuits(job, iqm_result_two_registers):
     for circuit_idx in range(2):
         assert result.get_memory(circuit_idx) == ['0100 11', '0100 10', '0100 01', '0100 10']
         assert result.get_counts(circuit_idx) == Counts({'0100 11': 1, '0100 10': 2, '0100 01': 1})
+    assert result.get_counts(QuantumCircuit(name='circuit_1')) == Counts({'0100 11': 1, '0100 10': 2, '0100 01': 1})
+    assert result.get_counts(QuantumCircuit(name='circuit_2')) == Counts({'0100 11': 1, '0100 10': 2, '0100 01': 1})
