@@ -23,3 +23,11 @@ def test_get_backend(tmp_path):
     provider = IQMProvider('http://some_url', str(settings_file))
     backend = provider.get_backend()
     assert isinstance(backend, IQMBackend)
+    assert backend.client._settings is not None
+
+
+def test_provider_with_default_settings():
+    provider = IQMProvider('http://some_url')
+    backend = provider.get_backend()
+    assert isinstance(backend, IQMBackend)
+    assert backend.client._settings is None
